Crate cp_cli_platform_project_euler

Crate cp_cli_platform_project_euler 

Bounded public Project Euler problem access

Structs

ArchivePage
Client
Difficulty
Problem
ProblemCatalog
Every public Project Euler problem listed by its compact catalogue endpoint
ProblemSummary
RecentProblems

Enums

Error

Constants

PROBLEM_CONTENT_ATTRIBUTION
Required source credit for displayed Project Euler problem content
PROBLEM_CONTENT_LICENSE
The licence applied by Project Euler to archive and recent problem content
PROBLEM_CONTENT_LICENSE_URL
The official Project Euler licence page